window.Gleam.initSearch([{"doc":"frac","title":"frac","content":"# 🧮 frac\n\n[![Package Version](https://img.shields.io/hexpm/v/frac)](https://hex.pm/packages/frac)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/frac/)\n\nWork with fractions in Gleam!\n\n```gleam\nimport frac\n\npub fn main() {\n  let result =\n    frac.new(1, 2)\n    |&gt; frac.add(frac.new(1, 3))\n\n  let assert True = result == frac.new(5, 6)\n}\n```\n\nTo add this package to your project you can:\n\n```sh\ngleam add frac@1\n```\n","url":"index.html"},{"doc":"frac","title":"Fraction","content":"pub opaque type Fraction\n A [simple fraction](https://en.wikipedia.org/wiki/Fraction#Simple,_common,_or_vulgar_fractions)\n with an integer numerator and denominator.\n\n\nSynonyms:\nfrac.Fraction\nfrac Fraction","url":"frac.html#Fraction"},{"doc":"frac","title":"add","content":"pub fn add(one: Fraction, other: Fraction) -&gt; Fraction\n Adds two fractions together.\n\n ## Examples\n\n \n assert sum(new(2, 4), new(3, 4)) == new(5, 4)\n \n\nSynonyms:\nfrac.add\nfrac add","url":"frac.html#add"},{"doc":"frac","title":"approximate","content":"pub fn approximate(\n  from float: Float,\n  max_denominator limit: Int,\n) -&gt; Fraction\n Approximates a float into a simple fraction whose denominator is at most\n `max_denominator`.\n\n &gt; ⚠️ This might result in a fraction that does not exactly yield the\n &gt; float number passed in as input. Precision only goes as far as 5 decimal\n &gt; digits.\n\n ## Examples\n\n \n assert approximate(0.333, 10) == new(1, 3)\n assert approximate(0.2, 10) == new(1, 5)\n \n\nSynonyms:\nfrac.approximate\nfrac approximate","url":"frac.html#approximate"},{"doc":"frac","title":"compare","content":"pub fn compare(one: Fraction, with other: Fraction) -&gt; Order\n Compares two fractions.\n\n ## Examples\n\n \n assert compare(new(1, 2), new(3, 2)) == Lt\n assert compare(new(1, 2), new(1, 2)) == Eq\n assert compare(new(1, 2), new(1, 3)) == Gt\n \n\nSynonyms:\nfrac.compare\nfrac compare","url":"frac.html#compare"},{"doc":"frac","title":"denominator","content":"pub fn denominator(fraction: Fraction) -&gt; Int\n Returns the denominator of a fraction.\n\nSynonyms:\nfrac.denominator\nfrac denominator","url":"frac.html#denominator"},{"doc":"frac","title":"divide","content":"pub fn divide(one: Fraction, by other: Fraction) -&gt; Fraction\n Divides one fraction by another.\n\n ## Examples\n\n \n assert divide(new(2, 4), new(1, 3)) == new(3, 2)\n \n\nSynonyms:\nfrac.divide\nfrac divide","url":"frac.html#divide"},{"doc":"frac","title":"from_int","content":"pub fn from_int(numerator: Int) -&gt; Fraction\n Creates a new fraction with the given nominator and denominator 1.\n\n ## Examples\n\n \n assert numerator(from_int(10)) == 10\n assert denominator(from_int(10)) == 1\n \n\nSynonyms:\nfrac.from_int\nfrac from_int","url":"frac.html#from_int"},{"doc":"frac","title":"multiply","content":"pub fn multiply(one: Fraction, by other: Fraction) -&gt; Fraction\n Multiplies one fraction by another.\n\n ## Examples\n\n \n assert multiply(new(1, 2), by: new(4, 5)) == new(2, 5)\n \n\nSynonyms:\nfrac.multiply\nfrac multiply","url":"frac.html#multiply"},{"doc":"frac","title":"new","content":"pub fn new(\n  numerator numerator: Int,\n  denominator denominator: Int,\n) -&gt; Fraction\n Creates a new fraction with the given numerator and denominator.\n\n &gt; Note that this function ensures that only the numerator can be negative,\n &gt; so `new(1, -2)` will be the same as `new(-1, 2)`.\n\n ## Examples\n\n \n assert numerator(new(1, 2)) == 1\n assert denominator(new(1, 2)) == 2\n \n\nSynonyms:\nfrac.new\nfrac new","url":"frac.html#new"},{"doc":"frac","title":"numerator","content":"pub fn numerator(fraction: Fraction) -&gt; Int\n Returns the numerator of a fraction.\n\nSynonyms:\nfrac.numerator\nfrac numerator","url":"frac.html#numerator"},{"doc":"frac","title":"subtract","content":"pub fn subtract(one: Fraction, other: Fraction) -&gt; Fraction\n Subtracts one fraction from another.\n\n ## Examples\n\n \n assert subtract(new(2, 4), new(3, 4)) == new(-1, 4)\n \n\nSynonyms:\nfrac.subtract\nfrac subtract","url":"frac.html#subtract"},{"doc":"frac","title":"to_float","content":"pub fn to_float(fraction: Fraction) -&gt; Float\n Returns the floating point number you get by dividing the numerator of a\n fraction by its denominator.\n\n &gt; Note that if the denominator is `0` you&#39;ll get `0` as the result.\n\n ## Examples\n\n \n assert to_float(new(3, 2)) == 1.5\n assert to_float(new(2, 0)) == 0.0\n \n\nSynonyms:\nfrac.to_float\nfrac to_float","url":"frac.html#to_float"},{"doc":"frac","title":"to_mixed_numbers","content":"pub fn to_mixed_numbers(fraction: Fraction) -&gt; #(Int, Fraction)\n Turns the fraction into a\n [mixed number](https://en.wikipedia.org/wiki/Fraction#Mixed_numbers): that\n is an integer and a\n [proper fraction](https://en.wikipedia.org/wiki/Fraction#Proper_and_improper_fractions)\n that added together produce the original fraction.\n\n ## Examples\n\n \n assert to_mixed_numbers(new(11, 4)) == #(2, new(3, 4))\n // 2 + 3/4 is equal to 11/4\n \n\nSynonyms:\nfrac.to_mixed_numbers\nfrac to_mixed_numbers","url":"frac.html#to_mixed_numbers"},{"doc":"frac","title":"frac","content":" This module has many functions to deal with\n [simple fractions](https://en.wikipedia.org/wiki/Fraction#Simple,_common,_or_vulgar_fractions):\n fractions with an integer numerator and denominator.\n\n | If you need to...             | You can use...                                                               |\n |-------------------------------|------------------------------------------------------------------------------|\n | create a fraction             | [new](#new), [from_int](#from_int), [approximate](#approximate)              |\n | get the numerator/denominator | [numerator](#numerator), [denominator](#denominator)                         |\n | simplify a fraction           | [to_mixed_numbers](#to_mixed_numbers)                                        |\n | combine fractions together    | [add](#add), [subtract](#subtract), [multiply](#multiply), [divide](#divide) |\n | turn a fraction into a float  | [to_float](#to_float)                                                        |\n | compare fractions             | [compare](#compare)                                                          |\n","url":"frac.html"}]);